@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: cmd85.c 732 2004-05-28 21:05:39Z roms $ */
+/* $Id: cmd85.c 1397 2005-07-20 10:55:03Z roms $ */
 
 /*  libticalcs - Ti Calculator library, a part of the TiLP project
  *  Copyright (C) 1999-2004  Romain Lievin
@@ -48,7 +48,7 @@ int ti85_send_VAR(uint16_t varsize, uint8_t vartype, char *varname)
   uint8_t buffer[16];
   uint8_t trans[9];
 
-  tifiles_translate_varname(varname, trans, vartype);
+  tifiles_translate_varname(varname, (char*)trans, vartype);
   printl2(0, " PC->TI: VAR (size=0x%04X=%i, id=%02X, name=<%s>)\n",
 	  varsize, varsize, vartype, trans);
 
@@ -150,7 +150,7 @@ int ti85_send_REQ(uint16_t varsize, uint8_t vartype, char *varname)
   uint8_t buffer[16] = { 0 };
   uint8_t trans[9];
 
-  tifiles_translate_varname(varname, trans, vartype);
+  tifiles_translate_varname(varname, (char*)trans, vartype);
   printl2(0, " PC->TI: REQ (size=0x%04X=%i, id=%02X, name=<%s>)\n",
 	  varsize, varsize, vartype, trans);
 
@@ -178,7 +178,7 @@ int ti85_send_RTS(uint16_t varsize, uint8_t vartype, char *varname)
   uint8_t buffer[16];
   uint8_t trans[9];
 
-  tifiles_translate_varname(varname, trans, vartype);
+  tifiles_translate_varname(varname, (char*)trans, vartype);
   printl2(0, " PC->TI: RTS (size=0x%04X=%i, id=%02X, name=<%s>)\n",
 	  varsize, varsize, vartype, trans);
 
@@ -197,7 +197,7 @@ int ti85_send_RTS(uint16_t varsize, uint8_t vartype, char *varname)
 int ti85_recv_VAR(uint16_t * varsize, uint8_t * vartype, char *varname)
 {
   uint8_t host, cmd;
-  uint8_t buffer[16] = { 0 };
+  uint8_t buffer[65536+6] = { 0 };
   uint16_t length;
   uint8_t trans[9];
   uint8_t strl;
@@ -222,7 +222,7 @@ int ti85_recv_VAR(uint16_t * varsize, uint8_t * vartype, char *varname)
     memcpy(varname, buffer + 3, 8);
   }
 
-  tifiles_translate_varname(varname, trans, *vartype);
+  tifiles_translate_varname(varname, (char*)trans, *vartype);
   printl2(0, " (size=0x%04X=%i, id=%02X, name=<%s>)",
 	  *varsize, *varsize, *vartype, trans);
   printl2(0, ".\n");
@@ -312,7 +312,7 @@ int ti85_recv_ACK(uint16_t * status)
 int ti85_recv_RTS(uint16_t * varsize, uint8_t * vartype, char *varname)
 {
   uint8_t host, cmd;
-  uint8_t buffer[16];
+  uint8_t buffer[65536+6];
   uint8_t trans[9];
   uint8_t strl;
 
@@ -326,7 +326,7 @@ int ti85_recv_RTS(uint16_t * varsize, uint8_t * vartype, char *varname)
   memcpy(varname, buffer + 4, strl);
   varname[strl] = '\0';
 
-  tifiles_translate_varname(varname, trans, *vartype);
+  tifiles_translate_varname(varname, (char*)trans, *vartype);
   printl2(0, " (size=0x%04X=%i, id=%02X, name=<%s>)",
 	  *varsize, *varsize, *vartype, trans);
   printl2(0, ".\n");
