@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: packets.h 788 2004-09-19 10:54:50Z roms $ */
+/* $Id: packets.h 1397 2005-07-20 10:55:03Z roms $ */
 
 /*  libticalcs - Ti Calculator library, a part of the TiLP project
  *  Copyright (C) 1999-2004  Romain Lievin
@@ -106,7 +106,7 @@ int send_packet(uint8_t target, uint8_t cmd, uint16_t length,
 int recv_packet(uint8_t * host, uint8_t * cmd, uint16_t * length,
 		uint8_t * data);
 
-void pad_buffer(char *varname, uint8_t value);
+void pad_buffer(uint8_t* varname, uint8_t value);
 
 #ifndef WORDS_BIGENDIAN
 # define fixup(x) (x &= 0x0000ffff)
